# ShiftyFace

A simple python module for generating random images with rarity level you dictate and assets you provide. The primary use case being the generation of images which can be turned into NFTs.

